==> lxqt-admin_1.1.0.orig.tar.xz: lxqt-admin-1.1.0/lxqt-admin-time/translations/lxqt-admin-time_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>الوقت:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>التّاريخ:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>فعّل مزامنة وقت الشبكة (NTP)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>ساعة الحاسوب الفعلية هي بالوقت المحلي</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <location filename="../nosdtimedatectl.cpp" line="141"/>
        <source>lxqt-admin-time-helper</source>
        <translation>‌lxqt-admin-time-helper</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <location filename="../nosdtimedatectl.cpp" line="142"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;فشل الإجراء (%1):&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>ضبط الوقت والتاريخ</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>الوقت والتاريخ</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>المنطقة الزمنية</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="122"/>
        <location filename="../timeadmindialog.cpp" line="132"/>
        <location filename="../timeadmindialog.cpp" line="139"/>
        <location filename="../timeadmindialog.cpp" line="149"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="156"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="156"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="157"/>
        <source>Reboot required</source>
        <translation>إعادة الإقلاع مطلوبة</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>المنطقة الزمنية الحالية:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>رشّح</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>بلا</translation>
    </message>
</context>
</TS>

==> lxqt-admin_1.4.0.orig.tar.xz: lxqt-admin-1.4.0/lxqt-admin-time/translations/lxqt-admin-time_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>الوقت:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>التّاريخ:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>فعّل مزامنة وقت الشبكة (NTP)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>ساعة الحاسوب الفعلية هي بالوقت المحلي</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <location filename="../nosdtimedatectl.cpp" line="141"/>
        <source>lxqt-admin-time-helper</source>
        <translation>‌lxqt-admin-time-helper</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <location filename="../nosdtimedatectl.cpp" line="142"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;فشل الإجراء (%1):&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>ضبط الوقت والتاريخ</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>الوقت والتاريخ</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>المنطقة الزمنية</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="122"/>
        <location filename="../timeadmindialog.cpp" line="132"/>
        <location filename="../timeadmindialog.cpp" line="139"/>
        <location filename="../timeadmindialog.cpp" line="149"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="156"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation>يتطلب تغيير RTC ليكون بالتوقيت المحلي إعادة التشغيل</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="156"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation>يتطلب تغيير RTC ليكون في UTC إعادة التشغيل</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="157"/>
        <source>Reboot required</source>
        <translation>إعادة الإقلاع مطلوبة</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>المنطقة الزمنية الحالية:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>رشّح</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>بلا</translation>
    </message>
</context>
</TS>
